"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = __importDefault(require("config"));
const util_1 = require("@storefront-api/lib/util");
const logger_1 = __importDefault(require("@storefront-api/lib/logger"));
/**
 * Adjust the config provided to the current store selected via request params
 * @param Object config configuration
 * @param Express request req
 */
function multiStoreConfig(apiConfig, req) {
    let confCopy = Object.assign({}, apiConfig);
    let storeCode = util_1.getCurrentStoreCode(req);
    const availableStores = config_1.default.get('availableStores');
    const magento1Config = config_1.default.get('magento1');
    if (storeCode && availableStores.indexOf(storeCode) >= 0) {
        if (magento1Config['api_' + storeCode]) {
            confCopy = Object.assign({}, magento1Config['api_' + storeCode]); // we're to use the specific api configuration - maybe even separate magento instance
        }
        else {
            if (new RegExp('(/' + availableStores.join('|') + '/)', 'gm').exec(confCopy.url) === null) {
                confCopy.url = (confCopy.url).replace(/(vsbridge)/gm, `${storeCode}/$1`);
            }
        }
    }
    else {
        if (storeCode) {
            logger_1.default.error('Unavailable store code', storeCode);
        }
    }
    return confCopy;
}
exports.multiStoreConfig = multiStoreConfig;
